LoonDocumentActionBuilder class

Inheritance
  • Object
  • HasteActionBuilder
  • LoonDocumentActionBuilder

Constructors

LoonDocumentActionBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call<T>(Document<T> doc) → DocumentSnapshot<T>?
init<T>(Document<T> initializer(), {Key? key}) → DocumentSnapshot<T>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild<S extends HasteAction>(Key? key, S actionBuilder()) → S
Builds the HasteAction of type S at the current action index using actionBuilder. If an existing action of type S exists at the current index, then rebuilding is skipped conditional on a matching key.
inherited
retrieve<S extends HasteAction>() → S?
Returns the HasteAction of type S if it exists at the current action index being evaluated.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance LoonDocumentActionBuilder
final