LoonQueryAction<T> class

Inheritance
  • Object
  • HasteAction
  • LoonQueryAction

Constructors

LoonQueryAction(Queryable<T> queryable)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
override
markNeedsBuild() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited