rebuild<S extends HasteAction> method
Builds the HasteAction of type S at the current action index using actionBuilder. If an existing action of type S
exists at the current index, then rebuilding is skipped conditional on a matching key.
Implementation
S rebuild<S extends HasteAction>(Key? key, S Function() actionBuilder) =>
_element._rebuildAction(key, actionBuilder);